/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.ercp.examples.background;

import org.eclipse.ercp.swt.mobile.ListBox;
import org.eclipse.ercp.swt.mobile.ListBoxItem;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.ImageData;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.part.ViewPart;


/**
 * <p>
 */

public class NormalView extends ViewPart implements SelectionListener {

	private Composite parent;
	private int imageNumber = 0;
	private final int MAX_IMAGES = 3;
	private Image[] backgrounds = new Image[MAX_IMAGES];
	private Point ssize;
	
	/**
	 * The constructor.
	 */
	public NormalView() {
	}

	/**
	 * This is a callback that will allow us to create the viewer and initialize
	 * it.
	 */
	public void createPartControl(Composite parent) {
			Color black = parent.getShell().getDisplay().getSystemColor(SWT.COLOR_BLACK);
			Color white = parent.getShell().getDisplay().getSystemColor(SWT.COLOR_WHITE);

			parent.getShell().setBackground(parent.getShell().getDisplay().getSystemColor(SWT.COLOR_CYAN));
			parent.getShell().setLayout(new FillLayout());
			
			this.parent = parent;
			RowLayout layout = new RowLayout(SWT.VERTICAL);
			layout.marginLeft = layout.marginRight = layout.marginTop = layout.marginBottom = 0;

			parent.setLayout(new RowLayout(SWT.VERTICAL));
		
			ssize = parent.getShell().getSize();
			setCompositeBackground();
			parent.setBackgroundMode(SWT.INHERIT_FORCE);
			
			Label l1 = new Label(parent, SWT.NONE);
			l1.setForeground(white);
			l1.setBackground(white);
			l1.setText("This is a simple label");
			
			ListBox lb = new ListBox(parent, SWT.NONE, ListBox.LB_STYLE_2LINE_ITEM | ListBox.LB_MOD_SHOW_HEADING_ICONS);
			lb.setForeground(white);
			lb.setBackground(white);
			ListBoxItem[] items = new ListBoxItem[3];

			// Get images
			Image lb1heading = new Image(parent.getDisplay(), getClass().getResourceAsStream("/res/lb1heading.png")); //$NON-NLS-1$
			Image lb2heading = new Image(parent.getDisplay(), getClass().getResourceAsStream("/res/lb2heading.png")); //$NON-NLS-1$
			Image lb3heading = new Image(parent.getDisplay(), getClass().getResourceAsStream("/res/lb3heading.png")); //$NON-NLS-1$

			items[0] = new ListBoxItem("details",null,"ListBox item #1",lb1heading); //$NON-NLS-1$ //$NON-NLS-2$
			items[1] = new ListBoxItem("details",null,"ListBox item #2",lb2heading); //$NON-NLS-1$ //$NON-NLS-2$
			items[2] = new ListBoxItem("details",null,"ListBox item #3",lb3heading); //$NON-NLS-1$ //$NON-NLS-2$
			lb.setDataModel(items);
			
			Text t1 = new Text(parent, SWT.NONE);
			t1.setForeground(black);
			t1.setText("Enter your text here"); //$NON-NLS-1$
			
			Button b = new Button(parent, SWT.BORDER);
			b.setText("Change Background");
			b.addSelectionListener(this);

			parent.layout();
	}
	
	void setCompositeBackground() {
		if (backgrounds[imageNumber] == null) {
			backgrounds[imageNumber] = new Image(parent.getDisplay(),
				getClass().getResourceAsStream("/res/greens" + imageNumber + ".jpg"));	//$NON-NLS-1$
		}	
		parent.setBackgroundImage(backgrounds[imageNumber]);
		
		if (++imageNumber == MAX_IMAGES)
			imageNumber = 0;
	}
	
	/**
	 * Passing the focus request to the viewer's control.
	 */
	public void setFocus() {
	}
	
	public void widgetSelected(SelectionEvent event) {
		setCompositeBackground();
	}
	
	public void widgetDefaultSelected(SelectionEvent event) {
		setCompositeBackground();
	}
}